@@ -19,7 +19,7 @@
 ;; URL:              https://github.com/meedstrom/el-job
 ;; Created:          2024-10-30
 ;; Keywords:         processes
-;; Package-Version:  2.4.6
+;; Package-Version:  2.4.7
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -93,6 +93,7 @@ See wrapper `el-job--ensure-compiled-lib' for a convenient way to return
 an .eln anyway, without your having to recompile on save."
   (cl-loop
    for (file . elems) in load-history
+   ;; FIXME: If a file has more than one `provide', this only finds the first.
    when (eq feature (cdr (assq 'provide elems)))
    return
    ;; Look for a natively-compiled function supposedly defined in FILE.
@@ -308,7 +309,7 @@ Cf. `with-slots' in the \"eieio\" library, or `let-alist'.
 
 For clarity inside BODY, each symbol name in SLOTS must be prepended
 with one character of your choosing, such as a dot."
-  (declare (indent 2))
+  (declare (indent 2) (debug (sexp sexp &rest form)))
   `(cl-symbol-macrolet
        ,(cl-loop
          for slot in slots
@@ -623,31 +624,33 @@ should trigger `el-job--handle-output'."
 For each where it is complete, handle it.  For the rest, check again
 after a short delay.  N is the count of checks done so far."
   (cl-assert (not (null bufs)))
-  (let (busy-bufs)
-    (save-current-buffer
-      (dolist (buf bufs)
-        (if (not (buffer-live-p buf))
-            (el-job--dbg 2 "Dead process buffer (this may be normal)")
-          (set-buffer buf)
-          (if (eq (char-before) ?\n)
-              (el-job--handle-output)
-            (push buf busy-bufs))))
-      (cl-assert el-job-here)
-      (if busy-bufs
-          (if (<= n 42)
-              (setf (el-job-timer el-job-here)
-                    (run-with-timer
-                     (/ n 32.0) nil #'el-job--poll (1+ n) busy-bufs))
-            (el-job--disable el-job-here)
-            (el-job--dbg 0 "Timed out, was busy for 30+ seconds: %s"
-                         (el-job-id el-job-here)))
+  (if (cl-notany #'buffer-live-p bufs)
+      (el-job--dbg 0 "No process buffers alive when `el-job--poll' called")
+    (let (busy-bufs)
+      (save-current-buffer
+        (dolist (buf bufs)
+          (if (not (buffer-live-p buf))
+              (el-job--dbg 2 "Dead process buffer (this may be normal)")
+            (set-buffer buf)
+            (if (eq (char-before) ?\n)
+                (el-job--handle-output)
+              (push buf busy-bufs))))
+        (cl-assert el-job-here)
         (when (member (el-job-timer el-job-here) timer-list)
           ;; It does, somehow, happen
           ;; https://github.com/meedstrom/org-node/issues/94
           (el-job--dbg 1 "Timer still active (this is a bug), recovering")
           (cancel-timer (el-job-timer el-job-here)))
-        (setf (el-job-timer el-job-here)
-              (run-with-timer 30 nil #'el-job--reap (current-buffer)))))))
+        (if busy-bufs
+            (if (<= n 42)
+                (setf (el-job-timer el-job-here)
+                      (run-with-timer
+                       (/ n 32.0) nil #'el-job--poll (1+ n) busy-bufs))
+              (el-job--disable el-job-here)
+              (el-job--dbg 0 "Timed out, was busy for 30+ seconds: %s"
+                           (el-job-id el-job-here)))
+          (setf (el-job-timer el-job-here)
+                (run-with-timer 30 nil #'el-job--reap (current-buffer))))))))
 
 (defun el-job--reap (buf)
   "If BUF is still alive, kill processes in the job associated with it."
